@@ -1,6 +1,8 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -69,7 +71,7 @@ const char *program = "dnstap-read";
 		}                                                     \
 	} while (0)
 
-ISC_NORETURN static void
+noreturn static void
 fatal(const char *format, ...);
 
 static void
