@@ -23,17 +23,20 @@ https://www.sphinx-doc.org/en/master/development/tutorials/recipe.html
 
 from collections import namedtuple
 
+from docutils.parsers.rst import directives
 from docutils import nodes
-from docutils.parsers.rst import Directive, directives
+
 from sphinx import addnodes
 from sphinx.directives import ObjectDescription
 from sphinx.domains import Domain
 from sphinx.roles import XRefRole
 from sphinx.util import logging
+from sphinx.util.docutils import SphinxDirective
 from sphinx.util.nodes import make_refnode
 
 import checkgrammar
 
+
 logger = logging.getLogger(__name__)
 
 
@@ -45,11 +48,10 @@ def split_csv(argument, required):
             "a non-empty list required; provide at least one value or remove"
             " this option"
         )
-    if not len(outlist) == len(set(outlist)):
-        raise ValueError("duplicate value detected")
     return outlist
 
 
+# pylint: disable=too-many-statements
 def domain_factory(domainname, domainlabel, todolist, grammar):
     """
     Return parametrized Sphinx domain object.
@@ -59,7 +61,7 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
                     See StatementListDirective.
     """
 
-    class StatementListDirective(Directive):
+    class StatementListDirective(SphinxDirective):
         """A custom directive to generate list of statements.
         It only installs placeholder which is later replaced by
         process_statementlist_nodes() callback.
@@ -72,8 +74,10 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
 
         def run(self):
             placeholder = todolist("")
-            placeholder["isc_filter_tags"] = self.options.get("filter_tags", [])
-            placeholder["isc_filter_blocks"] = self.options.get("filter_blocks", [])
+            placeholder["isc_filter_tags"] = set(self.options.get("filter_tags", []))
+            placeholder["isc_filter_blocks"] = set(
+                self.options.get("filter_blocks", [])
+            )
             return [placeholder]
 
     class ISCConfDomain(Domain):
@@ -124,7 +128,7 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
 
             @property
             def isc_tags(self):
-                return self.options.get("tags", [])
+                return set(self.options.get("tags", []))
 
             @property
             def isc_short(self):
@@ -223,16 +227,15 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
                 self.state.nested_parse(raw, self.content_offset, parsed)
                 return parsed
 
-            def transform_content(self, content_node: addnodes.desc_content) -> None:
+            def transform_content(self, contentnode: addnodes.desc_content) -> None:
                 """autogenerate content from structured data"""
-                self.workaround_transform_content = True
                 if self.isc_short:
-                    content_node.insert(0, self.isc_short_node)
+                    contentnode.insert(0, self.isc_short_node)
                 if self.isc_tags:
                     tags = nodes.paragraph()
                     tags += nodes.strong(text="Tags: ")
                     tags += nodes.Text(", ".join(self.isc_tags))
-                    content_node.insert(0, tags)
+                    contentnode.insert(0, tags)
 
                 iscconf = self.env.get_domain(domainname)
 
@@ -241,7 +244,7 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
                     return  # not defined in grammar, nothing to render
 
                 blocks = self.format_blocks(iscconf.statement_blocks[name])
-                content_node.insert(0, blocks)
+                contentnode.insert(0, blocks)
 
                 grammars = iscconf.statement_grammar_groups[name]
                 multi_grammar = len(grammars) > 1
@@ -254,24 +257,11 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
                     if "suppress_grammar" in self.options:
                         continue
                     grammarnode = self.format_grammar(multi_grammar, grammar_grp)
-                    content_node.insert(0, grammarnode)
+                    contentnode.insert(0, grammarnode)
 
                 warn = self.format_warnings(union_flags)
                 if len(warn):
-                    content_node.insert(0, warn)
-
-            def __init__(self, *args, **kwargs):
-                """Compability with Sphinx < 3.0.0"""
-                self.workaround_transform_content = False
-                super().__init__(*args, **kwargs)
-
-            def run(self):
-                """Compability with Sphinx < 3.0.0"""
-                nodelist = super().run()
-                if not self.workaround_transform_content:
-                    # get access to "contentnode" created inside super.run()
-                    self.transform_content(nodelist[1][-1])
-                return nodelist
+                    contentnode.insert(0, warn)
 
         name = domainname
         label = domainlabel
@@ -315,6 +305,7 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
                     ]
                 )
 
+        # pylint: disable=too-many-arguments
         def resolve_xref(self, env, fromdocname, builder, typ, target, node, contnode):
             """
             Sphinx API:
@@ -354,7 +345,7 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
             )
 
         def get_statement_name(self, signature):
-            return f"{domainname}.statement.{signature}"
+            return "{}.{}.{}".format(domainname, "statement", signature)
 
         def add_statement(self, signature, tags, short, short_node, lineno):
             """
@@ -362,7 +353,7 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
             No visible effect.
             """
             name = self.get_statement_name(signature)
-            anchor = f"{domainname}-statement-{signature}"
+            anchor = "{}-statement-{}".format(domainname, signature)
 
             new = {
                 "tags": tags,
@@ -471,11 +462,11 @@ def domain_factory(domainname, domainlabel, todolist, grammar):
                             lambda item: (
                                 (
                                     not acceptable_tags
-                                    or set(item["tags"]).intersection(acceptable_tags)
+                                    or item["tags"].intersection(acceptable_tags)
                                 )
                                 and (
                                     not acceptable_blocks
-                                    or set(item["block_names"]).intersection(
+                                    or item["block_names"].intersection(
                                         acceptable_blocks
                                     )
                                 )
@@ -556,7 +547,7 @@ class DictToDocutilsTableBuilder:
         row = nodes.row()
         for column in self.header:
             entry = nodes.entry()
-            entry += nodes.paragraph(text=column.description)
+            entry += nodes.Text(column.description)
             row += entry
 
         thead.append(row)
@@ -571,7 +562,7 @@ class DictToDocutilsTableBuilder:
                 entry = nodes.entry()
                 value = obj[column.dictkey]
                 if isinstance(value, str):
-                    value = nodes.paragraph(text=value)
+                    value = nodes.Text(value)
                 else:
                     value = value.deepcopy()
                 entry += value
