@@ -1,6 +1,8 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -16,7 +18,7 @@
 
 #define RRTYPE_RT_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_rt(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -58,7 +60,7 @@ fromtext_rt(ARGS_FROMTEXT) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_rt(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
@@ -84,7 +86,7 @@ totext_rt(ARGS_TOTEXT) {
 	return (dns_name_totext(&prefix, sub, target));
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_rt(ARGS_FROMWIRE) {
 	dns_name_t name;
 	isc_region_t sregion;
@@ -113,7 +115,7 @@ fromwire_rt(ARGS_FROMWIRE) {
 	return (dns_name_fromwire(&name, source, dctx, options, target));
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_rt(ARGS_TOWIRE) {
 	dns_name_t name;
 	dns_offsets_t offsets;
@@ -139,7 +141,7 @@ towire_rt(ARGS_TOWIRE) {
 	return (dns_name_towire(&name, cctx, target));
 }
 
-static inline int
+static int
 compare_rt(ARGS_COMPARE) {
 	dns_name_t name1;
 	dns_name_t name2;
@@ -173,7 +175,7 @@ compare_rt(ARGS_COMPARE) {
 	return (dns_name_rdatacompare(&name1, &name2));
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_rt(ARGS_FROMSTRUCT) {
 	dns_rdata_rt_t *rt = source;
 	isc_region_t region;
@@ -191,7 +193,7 @@ fromstruct_rt(ARGS_FROMSTRUCT) {
 	return (isc_buffer_copyregion(target, &region));
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_rt(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_rt_t *rt = target;
@@ -217,7 +219,7 @@ tostruct_rt(ARGS_TOSTRUCT) {
 	return (ISC_R_SUCCESS);
 }
 
-static inline void
+static void
 freestruct_rt(ARGS_FREESTRUCT) {
 	dns_rdata_rt_t *rt = source;
 
@@ -232,7 +234,7 @@ freestruct_rt(ARGS_FREESTRUCT) {
 	rt->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_rt(ARGS_ADDLDATA) {
 	dns_name_t name;
 	dns_offsets_t offsets;
@@ -259,7 +261,7 @@ additionaldata_rt(ARGS_ADDLDATA) {
 	return ((add)(arg, &name, dns_rdatatype_a, NULL));
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_rt(ARGS_DIGEST) {
 	isc_region_t r1, r2;
 	isc_result_t result;
@@ -280,7 +282,7 @@ digest_rt(ARGS_DIGEST) {
 	return (dns_name_digest(&name, digest, arg));
 }
 
-static inline bool
+static bool
 checkowner_rt(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_rt);
 
@@ -292,7 +294,7 @@ checkowner_rt(ARGS_CHECKOWNER) {
 	return (true);
 }
 
-static inline bool
+static bool
 checknames_rt(ARGS_CHECKNAMES) {
 	isc_region_t region;
 	dns_name_t name;
@@ -314,7 +316,7 @@ checknames_rt(ARGS_CHECKNAMES) {
 	return (true);
 }
 
-static inline int
+static int
 casecompare_rt(ARGS_COMPARE) {
 	return (compare_rt(rdata1, rdata2));
 }
