@@ -1,6 +1,8 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -35,11 +37,11 @@ isc_error_unexpected(const char *, int, const char *, ...)
 	ISC_FORMAT_PRINTF(3, 4);
 
 /*% fatal error */
-ISC_NORETURN void
+noreturn void
 isc_error_fatal(const char *, int, const char *, ...) ISC_FORMAT_PRINTF(3, 4);
 
 /*% runtimecheck error */
-ISC_NORETURN void
+noreturn void
 isc_error_runtimecheck(const char *, int, const char *);
 
 #define ISC_ERROR_RUNTIMECHECK(cond) \
