@@ -11,23 +11,20 @@
  * information regarding copyright ownership.
  */
 
-#include <inttypes.h>
 #include <sched.h> /* IWYU pragma: keep */
 #include <setjmp.h>
 #include <stdarg.h>
 #include <stddef.h>
 #include <string.h>
 
-/* Needs to be included before <cmocka.h> */
+/* For FIPS_mode() */
 #include <openssl/crypto.h>
 
 #define UNIT_TESTING
 #include <cmocka.h>
 
 #include <isc/buffer.h>
-#include <isc/crypto.h>
 #include <isc/hex.h>
-#include <isc/lib.h>
 #include <isc/md.h>
 #include <isc/region.h>
 #include <isc/result.h>
@@ -42,30 +39,30 @@ static int
 _setup(void **state) {
 	isc_md_t *md = isc_md_new();
 	if (md == NULL) {
-		return -1;
+		return (-1);
 	}
 	*state = md;
-	return 0;
+	return (0);
 }
 
 static int
 _teardown(void **state) {
 	if (*state == NULL) {
-		return -1;
+		return (-1);
 	}
 	isc_md_free(*state);
-	return 0;
+	return (0);
 }
 
 static int
 _reset(void **state) {
 	if (*state == NULL) {
-		return -1;
+		return (-1);
 	}
 	if (isc_md_reset(*state) != ISC_R_SUCCESS) {
-		return -1;
+		return (-1);
 	}
-	return 0;
+	return (0);
 }
 
 ISC_RUN_TEST_IMPL(isc_md_new) {
@@ -82,8 +79,8 @@ ISC_RUN_TEST_IMPL(isc_md_free) {
 }
 
 static void
-isc_md_test(isc_md_t *md, isc_md_type_t type, const char *buf, size_t buflen,
-	    const char *result, const size_t repeats) {
+isc_md_test(isc_md_t *md, const isc_md_type_t *type, const char *buf,
+	    size_t buflen, const char *result, const size_t repeats) {
 	isc_result_t res;
 
 	assert_non_null(md);
@@ -108,7 +105,7 @@ isc_md_test(isc_md_t *md, isc_md_type_t type, const char *buf, size_t buflen,
 
 	assert_return_code(res, ISC_R_SUCCESS);
 
-	assert_memory_equal(hexdigest, result, result ? strlen(result) : 0);
+	assert_memory_equal(hexdigest, result, (result ? strlen(result) : 0));
 	assert_int_equal(isc_md_reset(md), ISC_R_SUCCESS);
 }
 
@@ -118,15 +115,10 @@ ISC_RUN_TEST_IMPL(isc_md_init) {
 
 	expect_assert_failure(isc_md_init(NULL, ISC_MD_MD5));
 
-	assert_int_equal(isc_md_init(md, ISC_MD_UNKNOWN), ISC_R_NOTIMPLEMENTED);
+	assert_int_equal(isc_md_init(md, NULL), ISC_R_NOTIMPLEMENTED);
 
-	if (isc_crypto_fips_mode()) {
-		assert_int_equal(isc_md_init(md, ISC_MD_MD5),
-				 ISC_R_NOTIMPLEMENTED);
-	} else {
-		assert_int_equal(isc_md_init(md, ISC_MD_MD5), ISC_R_SUCCESS);
-		assert_int_equal(isc_md_reset(md), ISC_R_SUCCESS);
-	}
+	assert_int_equal(isc_md_init(md, ISC_MD_MD5), ISC_R_SUCCESS);
+	assert_int_equal(isc_md_reset(md), ISC_R_SUCCESS);
 
 	assert_int_equal(isc_md_init(md, ISC_MD_SHA1), ISC_R_SUCCESS);
 	assert_int_equal(isc_md_reset(md), ISC_R_SUCCESS);
@@ -159,8 +151,8 @@ ISC_RUN_TEST_IMPL(isc_md_update) {
 ISC_RUN_TEST_IMPL(isc_md_reset) {
 	isc_md_t *md = *state;
 #if 0
-	unsigned char digest[ISC_MAX_MD_SIZE] ISC_ATTR_UNUSED;
-	unsigned int digestlen ISC_ATTR_UNUSED;
+	unsigned char digest[ISC_MAX_MD_SIZE] __attribute((unused));
+	unsigned int digestlen __attribute((unused));
 #endif /* if 0 */
 
 	assert_non_null(md);
@@ -201,12 +193,6 @@ ISC_RUN_TEST_IMPL(isc_md_final) {
 
 ISC_RUN_TEST_IMPL(isc_md_md5) {
 	isc_md_t *md = *state;
-
-	if (isc_crypto_fips_mode()) {
-		skip();
-		return;
-	}
-
 	isc_md_test(md, ISC_MD_MD5, NULL, 0, NULL, 0);
 	isc_md_test(md, ISC_MD_MD5, TEST_INPUT(""),
 		    "D41D8CD98F00B204E9800998ECF8427E", 1);
