@@ -28,6 +28,7 @@
 #include <isc/refcount.h>
 #include <isc/sockaddr.h>
 #include <isc/thread.h>
+#include <isc/tls.h>
 #include <isc/util.h>
 
 #include "uv_wrap.h"
@@ -62,6 +63,7 @@ static isc_sockaddr_t tcp_listen_addr;
 static isc_sockaddr_t tcp_connect_addr;
 static isc_tlsctx_t *tcp_listen_tlsctx = NULL;
 static isc_tlsctx_t *tcp_connect_tlsctx = NULL;
+static isc_tlsctx_client_session_cache_t *tcp_tlsctx_client_sess_cache = NULL;
 
 static uint64_t send_magic = 0;
 static uint64_t stop_magic = 0;
@@ -333,6 +335,10 @@ setup_test(void **state __attribute__((unused))) {
 
 	isc_tlsctx_enable_dot_client_alpn(tcp_connect_tlsctx);
 
+	tcp_tlsctx_client_sess_cache = isc_tlsctx_client_session_cache_new(
+		mctx, tcp_connect_tlsctx,
+		ISC_TLSCTX_CLIENT_SESSION_CACHE_DEFAULT_SIZE);
+
 	return (0);
 }
 
@@ -361,6 +367,8 @@ teardown_test(void **state __attribute__((unused))) {
 	isc_refcount_destroy(&active_ssends);
 	isc_refcount_destroy(&active_sreads);
 
+	isc_tlsctx_client_session_cache_detach(&tcp_tlsctx_client_sess_cache);
+
 	return (0);
 }
 
@@ -1156,7 +1164,8 @@ stream_connect(isc_nm_cb_t cb, void *cbarg, unsigned int timeout,
 	if (stream_use_TLS) {
 		isc_nm_tlsconnect(connect_nm, &tcp_connect_addr,
 				  &tcp_listen_addr, cb, cbarg,
-				  tcp_connect_tlsctx, timeout, extrahandlesize);
+				  tcp_connect_tlsctx,
+				  tcp_tlsctx_client_sess_cache, timeout, 0);
 		return;
 	}
 #endif
@@ -2059,7 +2068,7 @@ static void
 tls_connect(isc_nm_t *nm) {
 	isc_nm_tlsconnect(nm, &tcp_connect_addr, &tcp_listen_addr,
 			  connect_connect_cb, NULL, tcp_connect_tlsctx,
-			  T_CONNECT, 0);
+			  tcp_tlsctx_client_sess_cache, T_CONNECT, 0);
 }
 
 ISC_RUN_TEST_IMPL(tls_noop) {
@@ -2220,7 +2229,7 @@ static void
 tlsdns_connect(isc_nm_t *nm) {
 	isc_nm_tlsdnsconnect(nm, &tcp_connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_CONNECT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 }
 
 ISC_RUN_TEST_IMPL(tlsdns_noop) {
@@ -2240,7 +2249,7 @@ ISC_RUN_TEST_IMPL(tlsdns_noop) {
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &tcp_connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_CONNECT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 
 	isc__netmgr_shutdown(connect_nm);
 
@@ -2267,7 +2276,7 @@ ISC_RUN_TEST_IMPL(tlsdns_noresponse) {
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_CONNECT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 
 	WAIT_FOR_EQ(cconnects, 1);
 	WAIT_FOR_EQ(csends, 1);
@@ -2321,7 +2330,7 @@ ISC_RUN_TEST_IMPL(tlsdns_timeout_recovery) {
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &tcp_connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_SOFT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 
 	WAIT_FOR_EQ(cconnects, 1);
 	WAIT_FOR_GE(csends, 1);
@@ -2352,7 +2361,7 @@ ISC_RUN_TEST_IMPL(tlsdns_recv_one) {
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &tcp_connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_CONNECT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 
 	WAIT_FOR_EQ(cconnects, 1);
 	WAIT_FOR_LE(nsends, 0);
@@ -2394,14 +2403,14 @@ ISC_RUN_TEST_IMPL(tlsdns_recv_two) {
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &tcp_connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_CONNECT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 
 	WAIT_FOR_EQ(cconnects, 1);
 
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &tcp_connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_CONNECT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 
 	WAIT_FOR_EQ(cconnects, 2);
 
@@ -2664,7 +2673,7 @@ ISC_RUN_TEST_IMPL(tlsdns_connect_noalpn) {
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &connect_addr, &tcp_listen_addr,
 			     tlsdns_connect_connect_noalpn, NULL, T_CONNECT, 0,
-			     connect_tlsctx_noalpn);
+			     connect_tlsctx_noalpn, NULL);
 
 	WAIT_FOR_EQ(active_cconnects, 0);
 
@@ -2730,7 +2739,7 @@ ISC_RUN_TEST_IMPL(tlsdns_listen_noalpn) {
 	isc_refcount_increment0(&active_cconnects);
 	isc_nm_tlsdnsconnect(connect_nm, &connect_addr, &tcp_listen_addr,
 			     connect_connect_cb, NULL, T_CONNECT, 0,
-			     tcp_connect_tlsctx);
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
 
 	WAIT_FOR_EQ(saccepts, 1);
 	WAIT_FOR_EQ(cconnects, 1);
